# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('encounters', '0002_initial'),
        ('locations', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='NutritionIntakeBasedOnReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakeCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakeNutritionItem',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('not_consumed', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakeNutritionItemConsumedItem',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakeNutritionItemTotalIntake',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakePartOfReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakePerformer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakePerformerActorReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakeReasonCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakeReasonReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakeReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntakeReportedReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='NutritionIntake',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('instantiates_uri', models.URLField(null=True)),
                ('status', models.CharField(choices=[('preparation', 'Preparation'), ('in-progress', 'In Progress'), ('not-done', 'Not Done'), ('on-hold', 'On Hold'), ('stopped', 'Stopped'), ('completed', 'Completed'), ('entered-in-error', 'Entered in Error'), ('unknown', 'Unknown')], max_length=200, null=True)),
                ('occurrence_date_time', models.DateTimeField(null=True)),
                ('recorded', models.DateTimeField(null=True)),
                ('reported_boolean', models.BooleanField(null=True)),
                ('code', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_code', to='base.codeableconcept')),
                ('derived_from', models.ManyToManyField(blank=True, related_name='nutrition_intake_derived_from', to='base.reference')),
                ('encounter', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_encounter', to='encounters.encounterreference')),
                ('identifier', models.ManyToManyField(blank=True, related_name='nutrition_intake_identifier', to='base.identifier')),
                ('location', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_location', to='locations.locationreference')),
                ('note', models.ManyToManyField(blank=True, related_name='nutrition_intake_note', to='base.annotation')),
                ('occurrence_period', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='nutrition_intake_occurrence_period', to='base.period')),
                ('status_reason', models.ManyToManyField(blank=True, related_name='nutrition_intake_status_reason', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""specimen serializers."""

from drf_writable_nested import WritableNestedModelSerializer

from dfhir.base.serializers import (
    AnnotationSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    DurationSerializer,
    IdentifierSerializer,
    PeriodSerializer,
    SimpleQuantitySerializer,
)
from dfhir.bodystructures.serializers import BodyStructureCodeableReferenceSerializer
from dfhir.devices.serializers import DeviceReferenceSerializer
from dfhir.procedures.serializers import ProcedureReferenceSerializer
from dfhir.servicerequests.serializers import ServiceRequestReferenceSerializer
from dfhir.specimens.models import (
    Specimen,
    SpecimenCollection,
    SpecimenCollectorReference,
    SpecimenContainer,
    SpecimenFeature,
    SpecimenProcessing,
    SpecimenProcessingPerformerReference,
    SpecimenReference,
    SpecimenSubjectReference,
)
from dfhir.substances.serializers import SubstanceReferenceSerializer


class SpecimenReferenceSerializer(BaseReferenceModelSerializer):
    """specimen reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta class."""

        model = SpecimenReference
        exclude = ["created_at", "updated_at"]


class SpecimenFeatureSerializer(WritableNestedModelSerializer):
    """specimen feature serializer."""

    type = CodeableConceptSerializer(required=False)

    class Meta:
        """meta class."""

        model = SpecimenFeature
        exclude = ["created_at", "updated_at"]


class SpecimenCollectorReferenceSerializer(BaseReferenceModelSerializer):
    """specimen collector reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta class."""

        model = SpecimenCollectorReference
        exclude = ["created_at", "updated_at"]


class SpecimenCollectionSerializer(WritableNestedModelSerializer):
    """specimen collection serializer."""

    collector = SpecimenCollectorReferenceSerializer(many=False, required=False)
    collected_period = PeriodSerializer(many=False, required=False)
    duration = DurationSerializer(many=False, required=False)
    quantity = SimpleQuantitySerializer(many=False, required=False)
    method = CodeableConceptSerializer(many=False, required=False)
    device = DeviceReferenceSerializer(many=False, required=False)
    procedure = ProcedureReferenceSerializer(many=False, required=False)
    body_site = BodyStructureCodeableReferenceSerializer(many=False, required=False)
    fasting_status_codeable_concept = CodeableConceptSerializer(
        many=False, required=False
    )
    fasting_status_duration = DurationSerializer(many=False, required=False)

    class Meta:
        """meta class."""

        model = SpecimenCollection
        exclude = ["created_at", "updated_at"]


class SpecimenPerformerReferenceSerializer(BaseReferenceModelSerializer):
    """specimen performer reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta class."""

        model = SpecimenProcessingPerformerReference
        exclude = ["created_at", "updated_at"]


class SpecimenProcessingSerializer(WritableNestedModelSerializer):
    """specimen processing serializer."""

    method = CodeableConceptSerializer(many=False, required=False)
    performer = SpecimenPerformerReferenceSerializer(many=False, required=False)
    device = DeviceReferenceSerializer(many=False, required=False)
    additive = SubstanceReferenceSerializer(many=True, required=False)
    time_period = PeriodSerializer(many=False, required=False)
    time_duration = DurationSerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = SpecimenProcessing
        exclude = ["created_at", "updated_at"]


class SpecimenContainerSerializer(WritableNestedModelSerializer):
    """specimen container serializer."""

    device = DeviceReferenceSerializer(many=False, required=False)
    specimen_quantity = SimpleQuantitySerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = SpecimenContainer
        exclude = ["created_at", "updated_at"]


class SpecimenSubjectReferenceSerializer(BaseReferenceModelSerializer):
    """specimen subject reference serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = SpecimenSubjectReference
        exclude = ["created_at", "updated_at"]


class SpecimenSerializer(BaseWritableNestedModelSerializer):
    """specimen serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    accession_identifier = IdentifierSerializer(many=False, required=False)
    type = CodeableConceptSerializer(many=False, required=False)
    subject = SpecimenSubjectReferenceSerializer(many=False, required=False)
    parent = SpecimenReferenceSerializer(many=True, required=False)
    request = ServiceRequestReferenceSerializer(many=True, required=False)
    role = CodeableConceptSerializer(many=True, required=False)
    feature = SpecimenFeatureSerializer(many=True, required=False)
    collections = SpecimenCollectionSerializer(many=False, required=False)
    processing = SpecimenProcessingSerializer(many=True, required=False)
    container = SpecimenContainerSerializer(many=True, required=False)
    condition = CodeableConceptSerializer(many=True, required=False)
    note = AnnotationSerializer(many=True, required=False)

    class Meta:
        """meta options."""

        model = Specimen
        exclude = ["created_at", "updated_at"]



"""immunization serializers."""

from drf_writable_nested import WritableNestedModelSerializer

from dfhir.base.serializers import (
    AnnotationSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    OrganizationReferenceSerializer,
    ReferenceSerializer,
    SimpleQuantitySerializer,
)
from dfhir.encounters.serializers import EncounterReferenceSerializer
from dfhir.immunizations.models import (
    Immunization,
    ImmunizationBasedOnReference,
    ImmunizationInformationSourceRefrence,
    ImmunizationPerformer,
    ImmunizationPerformerActorReference,
    ImmunizationProgramEligibility,
    ImmunizationProtocolApplied,
    ImmunizationReaction,
    ImmunizationReasonCodeableReference,
    ImmunizationReasonReference,
    ImmunizationReference,
)
from dfhir.locations.serializers import LocationReferenceSerializer
from dfhir.medications.serializers import (
    MedicationCodeableReferenceSerializer,
)
from dfhir.observations.serializers import (
    ObservationCodeableReferenceSerializer,
)
from dfhir.organizations.serializers import OrganizationCodeableReferenceSerializer
from dfhir.patients.serializers import PatientReferenceSerializer


class ImmunizationReferenceSerializer(BaseReferenceModelSerializer):
    """immunization reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationReference
        exclude = ["created_at", "updated_at"]


class ImmunizationBasedOnReferenceSerializer(BaseReferenceModelSerializer):
    """ImmunizationBasedOn reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationBasedOnReference
        exclude = ["created_at", "updated_at"]


class ImmunizationInformationSourceRefrenceSerializer(BaseReferenceModelSerializer):
    """ImmunizationInformationSource reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationInformationSourceRefrence
        exclude = ["created_at", "updated_at"]


class ImmunizationPerformerActorReferenceSerializer(BaseReferenceModelSerializer):
    """ImmunizationPerformerActor reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationPerformerActorReference
        exclude = ["created_at", "updated_at"]


class ImmunizationPerformerSerializer(WritableNestedModelSerializer):
    """ImmunizationPerformer serializer."""

    function = CodeableConceptSerializer(required=False)
    actor = ImmunizationPerformerActorReferenceSerializer()

    class Meta:
        """Meta options."""

        model = ImmunizationPerformer
        exclude = ["created_at", "updated_at"]


class ImmunizationProgramEligibilitySerializer(WritableNestedModelSerializer):
    """Immunization Program Eligibility serializer."""

    program = CodeableConceptSerializer(required=False)
    program_status = CodeableConceptSerializer(required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationProgramEligibility
        exclude = ["created_at", "updated_at"]


class ImmunizationProtocolAppliedSerializer(WritableNestedModelSerializer):
    """Immunization Protocol Applied serializer."""

    authority = OrganizationReferenceSerializer(required=False)
    usage_disease = CodeableConceptSerializer(many=True, required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationProtocolApplied
        exclude = ["created_at", "updated_at"]


class ImmunizationReactionSerializer(WritableNestedModelSerializer):
    """Immunization Reaction serializer."""

    manifestation = ObservationCodeableReferenceSerializer(required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationReaction
        exclude = ["created_at", "updated_at"]


class ImmunizationReasonReferenceSerializer(BaseReferenceModelSerializer):
    """ImmunizationReason reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationReasonReference
        exclude = ["created_at", "updated_at"]


class ImmunizationReasonCodeableReferenceSerializer(WritableNestedModelSerializer):
    """immunization reason codeable reference serializer."""

    concept = CodeableConceptSerializer(required=False)
    reference = ImmunizationReasonReferenceSerializer(required=False)

    class Meta:
        """Meta options."""

        model = ImmunizationReasonCodeableReference
        exclude = ["created_at", "updated_at"]


class ImmunizationSerializer(BaseWritableNestedModelSerializer):
    """Immunization serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    based_on = ImmunizationBasedOnReferenceSerializer(many=True, required=False)
    status_reason = CodeableConceptSerializer(many=False, required=False)
    vaccine_code = CodeableConceptSerializer(required=False)
    administered_product = MedicationCodeableReferenceSerializer(required=False)
    manufacturer = OrganizationCodeableReferenceSerializer(required=False)
    patient = PatientReferenceSerializer(required=False)
    encounter = EncounterReferenceSerializer(required=False)
    supporting_information = ReferenceSerializer(many=True, required=False)
    information_source = ImmunizationInformationSourceRefrenceSerializer(required=False)
    location = LocationReferenceSerializer(required=False)
    site = CodeableConceptSerializer(required=False)
    route = CodeableConceptSerializer(required=False)
    dose_quantity = SimpleQuantitySerializer(required=False)
    performer = ImmunizationPerformerSerializer(many=True, required=False)
    note = AnnotationSerializer(many=True, required=False)
    reason = ImmunizationReasonCodeableReferenceSerializer(many=True, required=False)
    sub_potent_reason = CodeableConceptSerializer(many=True, required=False)
    program_eligibility = ImmunizationProgramEligibilitySerializer(
        many=True, required=False
    )
    funding_source = CodeableConceptSerializer(required=False)
    reaction = ImmunizationReactionSerializer(many=True, required=False)
    protocol_applied = ImmunizationProtocolAppliedSerializer(many=True, required=False)

    class Meta:
        """meta options."""

        model = Immunization
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
        ('biologicallyderivedproducts', '0001_initial'),
        ('devices', '0001_initial'),
        ('inventoryitems', '0001_initial'),
        ('medications', '0001_initial'),
        ('nutritionproducts', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='inventoryiteminstance',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_instances_subjects', to='patients.patientorganizationreference'),
        ),
        migrations.AddField(
            model_name='inventoryitem',
            name='instance',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_items_insurances', to='inventoryitems.inventoryiteminstance'),
        ),
        migrations.AddField(
            model_name='inventoryitem',
            name='name',
            field=models.ManyToManyField(blank=True, related_name='inventory_items_names', to='inventoryitems.inventoryitemname'),
        ),
        migrations.AddField(
            model_name='inventoryitemproductreference',
            name='biologically_derived_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_product_references_biologicallyderived_product', to='biologicallyderivedproducts.biologicallyderivedproduct'),
        ),
        migrations.AddField(
            model_name='inventoryitemproductreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_product_reference_devices', to='devices.device'),
        ),
        migrations.AddField(
            model_name='inventoryitemproductreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_product_reference_identifiers', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='inventoryitemproductreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_product_reference_medications', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='inventoryitemproductreference',
            name='nutrition_product',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_product_references_nutrition_product', to='nutritionproducts.nutritionproduct'),
        ),
        migrations.AddField(
            model_name='inventoryitem',
            name='product_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_items_product_references', to='inventoryitems.inventoryitemproductreference'),
        ),
        migrations.AddField(
            model_name='inventoryitemreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_references_identifiers', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='inventoryitemreference',
            name='inventory_item',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_references_inventory_items', to='inventoryitems.inventoryitem'),
        ),
        migrations.AddField(
            model_name='inventoryitemresponsibleorganization',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='inventory_item_responsible_organization_codes', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='inventoryitemresponsibleorganization',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='inventory_item_responsible_organization_organizations', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='inventoryitem',
            name='responsible_organization',
            field=models.ManyToManyField(blank=True, related_name='inventory_items_responsible_organizations', to='inventoryitems.inventoryitemresponsibleorganization'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('devices', '0001_initial'),
        ('groups', '0003_initial'),
        ('locations', '0001_initial'),
        ('medications', '0001_initial'),
        ('molecularsequences', '0001_initial'),
        ('observations', '0002_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='observationbasedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='observation',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='observation_based_on', to='observations.observationbasedonreference'),
        ),
        migrations.AddField(
            model_name='observationbodystructurereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_body_structure_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='observationcodeablereference',
            name='concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='observation_codeable_reference_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='code',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='observation_component_code', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='data_absent_reason',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_component_data_absent_reason', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='interpretation',
            field=models.ManyToManyField(blank=True, related_name='observation_component_interpretation', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='value_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_component_value_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='value_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_component_value_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='value_period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_component_value_period', to='base.period'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='value_quantity',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='observation_component_value', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='value_range',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_component_value_range', to='base.range'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='value_ratio',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_component_value_ratio', to='base.ratio'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='value_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='molecularsequences.molecularsequencereference'),
        ),
        migrations.AddField(
            model_name='observation',
            name='component',
            field=models.ManyToManyField(blank=True, related_name='observation_component', to='observations.observationcomponent'),
        ),
        migrations.AddField(
            model_name='observationderivedfromreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_derived_from_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='observationderivedfromreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_derived_from_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='observation',
            name='derived_from',
            field=models.ManyToManyField(blank=True, related_name='observation_derived_from', to='observations.observationderivedfromreference'),
        ),
        migrations.AddField(
            model_name='observationhasmemberreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_has_member_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='observationhasmemberreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_has_member_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='observation',
            name='has_member',
            field=models.ManyToManyField(blank=True, related_name='observation_has_member', to='observations.observationhasmemberreference'),
        ),
        migrations.AddField(
            model_name='observationpartofreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_part_of_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='observation',
            name='part_of',
            field=models.ManyToManyField(blank=True, to='observations.observationpartofreference'),
        ),
        migrations.AddField(
            model_name='observationperformerreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_performer_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='observationperformerreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.identifier'),
        ),
        migrations.AddField(
            model_name='observationperformerreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='observationperformerreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='patients.patient'),
        ),
        migrations.AddField(
            model_name='observationperformerreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_performer_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='observationperformerreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_performer_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='observationperformerreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='observation',
            name='performer',
            field=models.ManyToManyField(blank=True, related_name='observation_performer', to='observations.observationperformerreference'),
        ),
        migrations.AddField(
            model_name='observationreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.identifier'),
        ),
        migrations.AddField(
            model_name='observationreference',
            name='observation',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_reference_observation', to='observations.observation'),
        ),
        migrations.AddField(
            model_name='observationcodeablereference',
            name='reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='observation_codeable_reference_reference', to='observations.observationreference'),
        ),
        migrations.AddField(
            model_name='observationreferencerange',
            name='age',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='reference_range_age', to='base.range'),
        ),
        migrations.AddField(
            model_name='observationreferencerange',
            name='applies_to',
            field=models.ManyToManyField(blank=True, related_name='reference_range_applies_to', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observationreferencerange',
            name='high',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='reference_range_high', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='observationreferencerange',
            name='low',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='reference_range_low', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='observationreferencerange',
            name='normal_value',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='reference_range_normal_value', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observationreferencerange',
            name='type',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='reference_range_type', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='reference_range',
            field=models.ManyToManyField(blank=True, to='observations.observationreferencerange'),
        ),
        migrations.AddField(
            model_name='observation',
            name='reference_range',
            field=models.ManyToManyField(blank=True, related_name='observation_reference_range', to='observations.observationreferencerange'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_subject_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_subject_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='base.identifier'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='locations.location'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='medications.medication'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='patients.patient'),
        ),
        migrations.AddField(
            model_name='observationsubjectreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='observation',
            name='subject',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='observation_subject', to='observations.observationsubjectreference'),
        ),
        migrations.AddField(
            model_name='observationtriggeredby',
            name='observation',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='triggered_by_observation', to='observations.observationreference'),
        ),
        migrations.AddField(
            model_name='observation',
            name='triggered_by',
            field=models.ManyToManyField(blank=True, related_name='observation_triggered_by', to='observations.observationtriggeredby'),
        ),
        migrations.AddField(
            model_name='sampleddata',
            name='origin',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='sampled_data_origin', to='base.quantity'),
        ),
        migrations.AddField(
            model_name='observationcomponent',
            name='value_sampled_data',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_component_value_sampled_data', to='observations.sampleddata'),
        ),
        migrations.AddField(
            model_name='observation',
            name='value_sampled_data',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_value_sampled_data', to='observations.sampleddata'),
        ),
        migrations.AddField(
            model_name='sampleddata',
            name='interval_unit',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='sampled_data_interval_unit', to='observations.sampleddataintervalunitcodes'),
        ),
    ]



"""activity definition views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.activitydefinitions.models import ActivityDefinition
from dfhir.activitydefinitions.serializers import ActivityDefinitionSerializer


class ActivityDefinitionListView(APIView):
    """activity definition list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses=ActivityDefinitionSerializer)
    def get(self, request):
        """Get activity definition objects."""
        activity_definitions = ActivityDefinition.objects.all()
        serializer = ActivityDefinitionSerializer(activity_definitions, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=ActivityDefinitionSerializer, responses=ActivityDefinitionSerializer
    )
    def post(self, request):
        """Create activity definition object."""
        serializer = ActivityDefinitionSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class ActivityDefinitionDetailView(APIView):
    """activity definition detail view."""

    def get_object(self, pk):
        """Get activity definition object."""
        try:
            return ActivityDefinition.objects.get(pk=pk)
        except ActivityDefinition.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses=ActivityDefinitionSerializer)
    def get(self, request, pk):
        """Get activity definition object."""
        activity_definition = self.get_object(pk)
        serializer = ActivityDefinitionSerializer(activity_definition)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=ActivityDefinitionSerializer, responses=ActivityDefinitionSerializer
    )
    def patch(self, request, pk):
        """Update activity definition object."""
        activity_definition = self.get_object(pk)
        serializer = ActivityDefinitionSerializer(
            activity_definition, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk):
        """Delete activity definition object."""
        activity_definition = self.get_object(pk)
        activity_definition.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""nutrition orders urls."""

from django.urls import path

from dfhir.nutritionorders.views import (
    NutritionOrderDetailView,
    NutritionOrderListView,
)

app_name = "nutritionorders"

urlpatterns = [
    path(
        "nutritionorders/",
        NutritionOrderListView.as_view(),
        name="nutrition-order-list",
    ),
    path(
        "nutritionorders/<int:pk>/",
        NutritionOrderDetailView.as_view(),
        name="nutrition-order-detail",
    ),
]



"""Appointment serializers."""

from drf_writable_nested.serializers import WritableNestedModelSerializer
from rest_framework import serializers

from dfhir.base.serializers import (
    AnnotationSerializer,
    BaseReferenceModelSerializer,
    BaseWritableNestedModelSerializer,
    CodeableConceptSerializer,
    CodingSerializer,
    IdentifierSerializer,
    PeriodSerializer,
    ReferenceSerializer,
    VirtualServiceDetailsSerializer,
)
from dfhir.healthcareservices.serializers import (
    HealthCareServiceCodeableReferenceSerializer,
)
from dfhir.patients.serializers import (
    PatientGroupReferenceSerializer,
)
from dfhir.slots.serializers import SlotReferenceSerializer

from .models import (
    Appointment,
    AppointmentBasedOnReference,
    AppointmentEncounterReason,
    AppointmentParticipant,
    AppointmentParticipantActor,
    AppointmentReasonCodeableReference,
    AppointmentReasonReference,
    AppointmentReference,
    DocumentReferenceBinaryCommunicationReference,
    MonthlyTemplate,
    RecurrenceTemplate,
    WeeklyTemplate,
    YearlyTemplate,
)


class AppointmentReferenceSerializer(BaseReferenceModelSerializer):
    """Appointment reference serializer."""

    class Meta:
        """Meta class."""

        model = AppointmentReference
        exclude = ["created_at", "updated_at"]


class AppointmentBasedOnReferenceSerializer(BaseReferenceModelSerializer):
    """Care Plan DeviceRequest MedicationRequest ServiceRequest Request Orchestration Nutrition Order Visual Prescripsion Immunization Recommendation Reference serializer."""

    identifier = IdentifierSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = AppointmentBasedOnReference
        exclude = ["created_at", "updated_at"]


class AppointmentReasonReferenceSerializer(BaseReferenceModelSerializer):
    """Condition Procedure Observation Immunization Recommendation Reference serializer."""

    identifier = IdentifierSerializer(required=False)

    class Meta:
        """Meta class."""

        model = AppointmentReasonReference
        exclude = ["created_at", "updated_at"]


class AppointmentReasonCodeableReferenceSerializer(WritableNestedModelSerializer):
    """Condition Procedure Observation Immunization Recommendation Codedable Reference serializer."""

    reference = AppointmentReasonReferenceSerializer(many=False, required=False)
    concept = CodeableConceptSerializer(many=False, required=False)

    class Meta:
        """Meta class."""

        model = AppointmentReasonCodeableReference
        exclude = ["created_at", "updated_at"]


class DocumentReferenceBinaryCommunicationReferenceSerializer(
    BaseReferenceModelSerializer
):
    """Document Reference Binary Communication Reference serializer."""

    identifier = IdentifierSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = DocumentReferenceBinaryCommunicationReference
        exclude = ["created_at", "updated_at"]


class WeeklyTemplateSerializer(serializers.ModelSerializer):
    """Weekly template serializer."""

    class Meta:
        """Meta class."""

        model = WeeklyTemplate
        exclude = ["created_at", "updated_at"]


class YearlyTemplateSerializer(serializers.ModelSerializer):
    """Yearly template serializer."""

    class Meta:
        """Meta class."""

        model = YearlyTemplate
        exclude = [
            "created_at",
            "updated_at",
        ]


class MonthlyTemplateSerializer(WritableNestedModelSerializer):
    """Monthly template serializer."""

    day_of_week = CodingSerializer(required=False)
    nth_week_of_month = CodingSerializer(required=False)

    class Meta:
        """Meta class."""

        model = MonthlyTemplate
        exclude = ["created_at", "updated_at"]


class RecurrenceTemplateSerializer(WritableNestedModelSerializer):
    """Recurrence template serializer."""

    weekly_template = WeeklyTemplateSerializer(required=False)
    monthly_template = MonthlyTemplateSerializer(required=False)
    time_zone = CodeableConceptSerializer(required=False)
    recurrence_type = CodeableConceptSerializer(required=False)

    class Meta:
        """Meta class."""

        model = RecurrenceTemplate
        exclude = ["created_at", "updated_at"]


class AppointmentParticipantActorSerializer(BaseReferenceModelSerializer):
    """Appointment actor serializer."""

    identifier = IdentifierSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = AppointmentParticipantActor
        exclude = ["created_at", "updated_at"]


class AppointmentParticipantSerializer(WritableNestedModelSerializer):
    """Participant serializer."""

    actor = AppointmentParticipantActorSerializer(required=False)
    type = CodeableConceptSerializer(many=True, required=False)
    period = PeriodSerializer(required=False)

    class Meta:
        """Meta class."""

        model = AppointmentParticipant
        exclude = ["created_at", "updated_at"]


class EncounterReasonSerializer(serializers.ModelSerializer):
    """Encounter reason serializer."""

    class Meta:
        """Meta class."""

        model = AppointmentEncounterReason
        exclude = ["created_at", "updated_at"]


class AppointmentSerializer(BaseWritableNestedModelSerializer):
    """Appointment serializer."""

    def get_fields(self):
        """Get fields."""
        from dfhir.accounts.serializers import AccountReferenceSerializer

        fields = super().get_fields()
        fields["account"] = AccountReferenceSerializer(many=True, required=False)
        return fields

    identifier = IdentifierSerializer(many=True, required=False)
    cancellation_reason = CodeableConceptSerializer(required=False)
    klass = CodeableConceptSerializer(many=True, required=False)
    service_category = CodeableConceptSerializer(many=True, required=False)
    service_type = HealthCareServiceCodeableReferenceSerializer(
        many=True, required=False
    )
    specialty = CodeableConceptSerializer(many=True, required=False)
    appointment_type = CodeableConceptSerializer(required=False)
    reason = AppointmentReasonCodeableReferenceSerializer(many=True, required=False)
    priority = CodeableConceptSerializer(required=False)
    replaces = AppointmentReferenceSerializer(many=True, required=False)
    virtual_service = VirtualServiceDetailsSerializer(many=True, required=False)
    supporting_information = ReferenceSerializer(many=True, required=False)
    previous_appointment = AppointmentReferenceSerializer(required=False)
    originating_appointment = AppointmentReferenceSerializer(required=False)
    requested_period = PeriodSerializer(many=True, required=False)
    slot = SlotReferenceSerializer(many=True, required=False)
    note = AnnotationSerializer(many=True, required=False)
    patient_instruction = DocumentReferenceBinaryCommunicationReferenceSerializer(
        many=True, required=False
    )
    based_on = AppointmentBasedOnReferenceSerializer(many=True, required=False)
    subject = PatientGroupReferenceSerializer(required=False)
    recurrence_template = RecurrenceTemplateSerializer(many=True, required=False)
    participant = AppointmentParticipantSerializer(many=True, required=False)

    class Meta:
        """Meta class."""

        model = Appointment
        exclude = ["created_at", "updated_at"]
        rename_fields = {
            "class": "klass",
        }

    # def validate(self, data):
    #     """Validate date time fields."""
    #     validate_date_time_fields(
    #         data.get("requested_start_date"), data.get("requested_end_date")
    #     )
    #     return data



"""Practitioner models."""

from django.db import models

from dfhir.base import choices as base_choices
from dfhir.base.models import (
    Address,
    Attachment,
    BaseReference,
    Communication,
    ContactPoint,
    HumanName,
    Identifier,
    Qualification,
    TimeStampedModel,
)


class PractitionerReference(BaseReference):
    """Practitioner reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="practitioner_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        "Practitioner",
        on_delete=models.CASCADE,
        related_name="practitioner_reference_practitioner",
        null=True,
    )


class Practitioner(TimeStampedModel):
    """Practitioner model."""

    identifier = models.ManyToManyField(
        Identifier, related_name="practitioner_identifier", blank=True
    )
    active = models.BooleanField(default=True)
    name = models.ManyToManyField(
        HumanName, related_name="practitioner_name", blank=True
    )
    telecom = models.ManyToManyField(
        ContactPoint, related_name="practitioner_telecom", blank=True
    )
    gender = models.CharField(
        max_length=20, choices=base_choices.GenderChoices.choices, null=True, blank=True
    )
    birth_date = models.DateField(null=True, blank=True)
    deceased_boolean = models.BooleanField(default=True)
    deceased_date_time = models.DateTimeField(null=True, blank=True)
    address = models.ManyToManyField(
        Address, related_name="practitioner_address", blank=True
    )
    photo = models.ManyToManyField(
        Attachment, related_name="practitioner_photo", blank=True
    )
    qualification = models.ManyToManyField(
        Qualification, related_name="practitioner_qualification", blank=True
    )
    communication = models.ManyToManyField(
        Communication, related_name="practitioner_communication", blank=True
    )


class PractitionerPractitionerRoleReference(BaseReference):
    """practitioner practitioner role reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="practitioner_practitioner_role_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        Practitioner,
        on_delete=models.CASCADE,
        related_name="practitioner_practitioner_role_reference_practitioner",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.CASCADE,
        related_name="practitioner_practitioner_role_reference_practitioner_role",
        null=True,
    )


class PractitionerOrganizationPractitionerRoleReference(BaseReference):
    """practitioner organization practitioner role reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.CASCADE,
        related_name="practitioner_organization_practitioner_role_reference_identifier",
        null=True,
    )
    practitioner = models.ForeignKey(
        Practitioner,
        on_delete=models.CASCADE,
        related_name="practitioner_organization_practitioner_role_reference_practitioner",
        null=True,
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.CASCADE,
        related_name="practitioner_organization_practitioner_role_reference_organization",
        null=True,
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.CASCADE,
        related_name="practitioner_organization_practitioner_role_reference_practitioner_role",
        null=True,
    )



"""Device urls."""

from django.urls import path

from . import views

app_name = "devices"

urlpatterns = [
    path("devices/", views.DeviceListView.as_view()),
    path("devices/<int:pk>/", views.DeviceDetailView.as_view()),
]



"""medication statement model choices."""

from django.db.models import TextChoices
from django.utils.translation import gettext_lazy as _


class MedicationStatementStatusChoices(TextChoices):
    """medication statement status choices."""

    RECORDED = "recorded", _("Recorded")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered in error")
    DRAFT = "draft", _("Draft")



"""payment reconciliation serializers."""

from drf_writable_nested import WritableNestedModelSerializer
from rest_framework import serializers

from dfhir.accounts.serializers import AccountReferenceSerializer
from dfhir.base.serializers import (
    BaseReferenceModelSerializer,
    CodeableConceptSerializer,
    IdentifierSerializer,
    MoneySerializer,
    PeriodSerializer,
)
from dfhir.encounters.serializers import EncounterReferenceSerializer
from dfhir.locations.serializers import LocationReferenceSerializer
from dfhir.paymentreconciliations.models import (
    OrganizationPractitionerPractitionerRoleReference,
    PaymentReconciliation,
    PaymentReconciliationAllocation,
    PaymentReconciliationAllocationTargetReference,
    PaymentReconciliationPaymentIssuerReference,
    PaymentReconciliationProcessNote,
    PaymentReconciliationReference,
)
from dfhir.practitionerroles.serializers import PractitionerRoleReferenceSerializer
from dfhir.tasks.serializers import TaskReferenceSerializer


class OrganizationPractitionerPractitionerRoleReferenceSerializer(
    BaseReferenceModelSerializer
):
    """Organization Practitioner Practitioner Role Reference Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = OrganizationPractitionerPractitionerRoleReference
        exclude = ["created_at", "updated_at"]


class PaymentReconciliationAllocationTargetReferenceSerializer(
    BaseReferenceModelSerializer
):
    """Payment Reconciliation Allocation Target Reference Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = PaymentReconciliationAllocationTargetReference
        exclude = ["created_at", "updated_at"]


class PaymentReconciliationPaymentIssuerReferenceSerializer(
    BaseReferenceModelSerializer
):
    """Payment Reconciliation Payment Issuer Reference Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = PaymentReconciliationPaymentIssuerReference
        exclude = ["created_at", "updated_at"]


class PaymentReconciliationAllocationSerializer(WritableNestedModelSerializer):
    """Payment Reconciliation Allocation Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)
    predecessor = IdentifierSerializer(many=False, required=False)
    target = PaymentReconciliationAllocationTargetReferenceSerializer(
        many=False, required=False
    )
    target_item_identifier = IdentifierSerializer(many=False, required=False)
    encounter = EncounterReferenceSerializer(many=False, required=False)
    account = AccountReferenceSerializer(many=False, required=False)
    type = CodeableConceptSerializer(many=False, required=False)
    submitter = OrganizationPractitionerPractitionerRoleReferenceSerializer(
        many=False, required=False
    )
    responsible = PractitionerRoleReferenceSerializer(required=False)
    payee = OrganizationPractitionerPractitionerRoleReferenceSerializer(
        many=False, required=False
    )
    amount = MoneySerializer(many=False, required=False)

    class Meta:
        """Meta options."""

        model = PaymentReconciliationAllocation
        exclude = ["created_at", "updated_at"]


class PaymentReconciliationProcessNoteSerializer(serializers.ModelSerializer):
    """payment reconciliation process note serializer."""

    class Meta:
        """Meta options."""

        model = PaymentReconciliationProcessNote
        exclude = ["created_at", "updated_at"]


class PaymentReconciliationSerializer(WritableNestedModelSerializer):
    """Payment Reconciliation Process Note Serializer."""

    identifier = IdentifierSerializer(many=True, required=False)
    type = CodeableConceptSerializer(many=False, required=False)
    kind = CodeableConceptSerializer(many=False, required=False)
    period = PeriodSerializer(many=False, required=False)
    enterer = OrganizationPractitionerPractitionerRoleReferenceSerializer(
        required=False
    )
    issuer_type = CodeableConceptSerializer(many=False, required=False)
    payment_issuer = PaymentReconciliationPaymentIssuerReferenceSerializer(
        many=False, required=False
    )
    request = TaskReferenceSerializer(required=False)
    requestor = OrganizationPractitionerPractitionerRoleReferenceSerializer(  # codespell:ignore requestor
        required=False
    )
    location = LocationReferenceSerializer(many=False, required=False)
    method = CodeableConceptSerializer(many=False, required=False)
    tendered_amount = MoneySerializer(many=False, required=False)
    returned_amount = MoneySerializer(many=False, required=False)
    amount = MoneySerializer(many=False, required=False)
    payment_identifier = IdentifierSerializer(many=False, required=False)
    allocation = PaymentReconciliationAllocationSerializer(many=True, required=False)
    form_code = CodeableConceptSerializer(required=False)
    process_note = PaymentReconciliationProcessNoteSerializer(many=True, required=False)

    class Meta:
        """meta options."""

        model = PaymentReconciliation
        exclude = ["created_at", "updated_at"]


class PaymentReconciliationReferenceSerializer(BaseReferenceModelSerializer):
    """Payment Reconciliation Reference Serializer."""

    identifier = IdentifierSerializer(many=False, required=False)

    class Meta:
        """meta options."""

        model = PaymentReconciliationReference
        exclude = ["created_at", "updated_at"]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('communications', '0003_initial'),
        ('devices', '0001_initial'),
        ('endpoints', '0001_initial'),
        ('groups', '0002_initial'),
        ('healthcareservices', '0001_initial'),
        ('locations', '0001_initial'),
        ('organizations', '0001_initial'),
        ('patients', '0002_initial'),
        ('practitionerroles', '0002_initial'),
        ('practitioners', '0001_initial'),
        ('relatedpersons', '0001_initial'),
        ('servicerequests', '0001_initial'),
        ('tasks', '0001_initial'),
        ('visionprescriptions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='service_request',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_service_request', to='servicerequests.servicerequest'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='task',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_task', to='tasks.task'),
        ),
        migrations.AddField(
            model_name='communicationbsedonreference',
            name='vision_prescription',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_based_on_reference_vision_prescription', to='visionprescriptions.visionprescription'),
        ),
        migrations.AddField(
            model_name='communication',
            name='based_on',
            field=models.ManyToManyField(blank=True, related_name='communication_based_on', to='communications.communicationbsedonreference'),
        ),
        migrations.AddField(
            model_name='communicationpayload',
            name='content_attachment',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_payload_content_attachment', to='base.attachment'),
        ),
        migrations.AddField(
            model_name='communicationpayload',
            name='content_codeable_concept',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_payload_content_codeable_concept', to='base.codeableconcept'),
        ),
        migrations.AddField(
            model_name='communicationpayload',
            name='content_reference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_payload_content_reference', to='base.reference'),
        ),
        migrations.AddField(
            model_name='communication',
            name='payload',
            field=models.ManyToManyField(blank=True, related_name='communication_payload', to='communications.communicationpayload'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='endpoint',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_endpoint', to='endpoints.endpoint'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='communicationrecipientreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_recipient_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='communication',
            name='recipient',
            field=models.ManyToManyField(blank=True, related_name='communication_recipient', to='communications.communicationrecipientreference'),
        ),
        migrations.AddField(
            model_name='communicationreference',
            name='communication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_reference_communication', to='communications.communication'),
        ),
        migrations.AddField(
            model_name='communicationreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communication',
            name='in_response_to',
            field=models.ManyToManyField(blank=True, related_name='communication_in_response_to', to='communications.communicationreference'),
        ),
        migrations.AddField(
            model_name='communicationrequestreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_request_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='care_team',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_care_team', to='careteams.careteam'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='device',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_device', to='devices.device'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='endpoint',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_endpoint', to='endpoints.endpoint'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_organization', to='organizations.organization'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='patient',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_patient', to='patients.patient'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='practitioner',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_practitioner', to='practitioners.practitioner'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='practitioner_role',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_practitioner_role', to='practitionerroles.practitionerrole'),
        ),
        migrations.AddField(
            model_name='communicationsenderreference',
            name='related_person',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender_reference_related_person', to='relatedpersons.relatedperson'),
        ),
        migrations.AddField(
            model_name='communication',
            name='sender',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='communication_sender', to='communications.communicationsenderreference'),
        ),
    ]



"""formulary item urls."""

from django.urls import path

from dfhir.formularyitems import views

app_name = "formularyitems"

urlpatterns = [
    path(
        "formularyitems/",
        views.FormularyItemListView.as_view(),
        name="formularyitem-list",
    ),
    path(
        "formularyitems/<int:pk>/",
        views.FormularyItemDetailView.as_view(),
        name="formularyitem-detail",
    ),
]



# Generated by Django 5.2 on 2025-05-05 14:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('observationdefinitions', '0001_initial'),
        ('specimendefinitions', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='observationdefinition',
            name='specimen',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='observation_definition_specimen', to='specimendefinitions.specimendefinition'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0005_initial'),
        ('careteams', '0004_initial'),
        ('episodeofcares', '0001_initial'),
        ('practitioners', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='episodeofcare',
            name='care_manager',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_care_manager', to='practitioners.practitionerpractitionerrolereference'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='care_team',
            field=models.ManyToManyField(blank=True, related_name='episode_of_care_care_team', to='careteams.careteamreference'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='identifier',
            field=models.ManyToManyField(blank=True, related_name='episode_of_care_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='managing_organization',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_managing_organization', to='base.organizationreference'),
        ),
        migrations.AddField(
            model_name='episodeofcare',
            name='period',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='episode_of_care_period', to='base.period'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0004_initial'),
        ('organizations', '0001_initial'),
        ('practitionerroles', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Practitioner',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('active', models.BooleanField(default=True)),
                ('gender', models.CharField(blank=True, choices=[('male', 'male'), ('female', 'female'), ('other', 'other'), ('unknown', 'unknown')], max_length=20, null=True)),
                ('birth_date', models.DateField(blank=True, null=True)),
                ('deceased_boolean', models.BooleanField(default=True)),
                ('deceased_date_time', models.DateTimeField(blank=True, null=True)),
                ('address', models.ManyToManyField(blank=True, related_name='practitioner_address', to='base.address')),
                ('communication', models.ManyToManyField(blank=True, related_name='practitioner_communication', to='base.communication')),
                ('identifier', models.ManyToManyField(blank=True, related_name='practitioner_identifier', to='base.identifier')),
                ('name', models.ManyToManyField(blank=True, related_name='practitioner_name', to='base.humanname')),
                ('photo', models.ManyToManyField(blank=True, related_name='practitioner_photo', to='base.attachment')),
                ('qualification', models.ManyToManyField(blank=True, related_name='practitioner_qualification', to='base.qualification')),
                ('telecom', models.ManyToManyField(blank=True, related_name='practitioner_telecom', to='base.contactpoint')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PractitionerOrganizationPractitionerRoleReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_organization_practitioner_role_reference_identifier', to='base.identifier')),
                ('organization', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_organization_practitioner_role_reference_organization', to='organizations.organization')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_organization_practitioner_role_reference_practitioner', to='practitioners.practitioner')),
                ('practitioner_role', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_organization_practitioner_role_reference_practitioner_role', to='practitionerroles.practitionerrole')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PractitionerPractitionerRoleReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_practitioner_role_reference_identifier', to='base.identifier')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_practitioner_role_reference_practitioner', to='practitioners.practitioner')),
                ('practitioner_role', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_practitioner_role_reference_practitioner_role', to='practitionerroles.practitionerrole')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='PractitionerReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('identifier', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_reference_identifier', to='base.identifier')),
                ('practitioner', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='practitioner_reference_practitioner', to='practitioners.practitioner')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""nutrition orders views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.nutritionorders.models import NutritionOrder
from dfhir.nutritionorders.serializers import NutritionOrderSerializer


class NutritionOrderListView(APIView):
    """nutrition order list API view."""

    permission_classes = [AllowAny]

    @extend_schema(
        responses={200: NutritionOrderSerializer(many=True)},
    )
    def get(self, request):
        """Get method."""
        nutrition_orders = NutritionOrder.objects.all()
        serializer = NutritionOrderSerializer(nutrition_orders, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=NutritionOrderSerializer, responses={201: NutritionOrderSerializer}
    )
    def post(self, request):
        """Create nutrition order object."""
        serializer = NutritionOrderSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class NutritionOrderDetailView(APIView):
    """nutrition order detail API view."""

    def get_object(self, pk):
        """Get nutrition order object."""
        try:
            return NutritionOrder.objects.get(pk=pk)
        except NutritionOrder.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: NutritionOrderSerializer})
    def get(self, request, pk):
        """Get method."""
        nutrition_order = self.get_object(pk)
        serializer = NutritionOrderSerializer(nutrition_order)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={200: NutritionOrder})
    def patch(self, request, pk):
        """Update nutrition order object."""
        nutrition_order = self.get_object(pk)
        serializer = NutritionOrderSerializer(
            nutrition_order, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: None})
    def delete(self, request, pk):
        """Delete nutrition order object."""
        nutrition_order = self.get_object(pk)
        nutrition_order.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



"""document reference models."""

from django.db import models

from dfhir.base.models import (
    BaseReference,
    CodeableConcept,
    CodeableReference,
    Coding,
    Identifier,
    Period,
    Reference,
    TimeStampedModel,
)
from dfhir.documentreferences.choices import (
    DocumentReferenceDocStatusChoices,
    DocumentReferenceStatusChoices,
)

# Create your models here.


class DocumentReferenceBasedOnReference(BaseReference):
    """document reference based on reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_references_identifier",
    )
    appointment = models.ForeignKey(
        "appointments.Appointment",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_appointment",
    )
    appointment_response = models.ForeignKey(
        "appointmentresponses.AppointmentResponse",
        null=True,
        on_delete=models.DO_NOTHING,
        related_name="document_reference_based_on_reference_appointment_response",
    )
    care_plan = models.ForeignKey(
        "careplans.CarePlan",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_care_plan",
    )
    claim = models.ForeignKey(
        "claims.Claim",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_claim",
    )
    # TODO: communication_request = models.ForeignKey(
    #     "communications.CommunicationRequest",
    #     on_delete=models.DO_NOTHING,
    #     null=True)
    contract = models.ForeignKey(
        "contracts.Contract",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_contract",
    )
    coverage_eligibility_request = models.ForeignKey(
        "coverageeligibilityrequests.CoverageEligibilityRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_coverage_eligibility_request",
    )
    device_request = models.ForeignKey(
        "devicerequests.DeviceRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_device_request",
    )
    enrollment_request = models.ForeignKey(
        "enrollmentrequests.EnrollmentRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_enrollment_request",
    )
    immunization_recommendation = models.ForeignKey(
        "immunizationrecommendations.ImmunizationRecommendation",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_immunization_recommendation",
    )
    medication_request = models.ForeignKey(
        "medicationrequests.MedicationRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_medication_request",
    )
    nutrition_order = models.ForeignKey(
        "nutritionorders.NutritionOrder",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_nutrition_order",
    )
    # TODO: request_orchestration = models.ForeignKey(
    #     "requestorchestrations.RequestOrchestration",
    #     on_delete=models.DO_NOTHING,
    #     null=True,
    #     related_name="document_reference_based_on_reference_request_orchestration",
    # )
    service_request = models.ForeignKey(
        "servicerequests.ServiceRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_service_request",
    )
    supply_request = models.ForeignKey(
        "supplyrequests.SupplyRequest",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_supply_request",
    )
    vision_prescription = models.ForeignKey(
        "visionprescriptions.VisionPrescription",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_based_on_reference_vision_prescription",
    )


class DocumentReferenceAuthorReference(BaseReference):
    """document reference author reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_references_identifier",
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_reference_practitioner",
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_reference_practitioner_role",
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_reference_organization",
    )
    device = models.ForeignKey(
        "devices.Device",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_reference_device",
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_reference_patient",
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_reference_related_person",
    )
    care_team = models.ForeignKey(
        "careteams.CareTeam",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_reference_care_team",
    )
    group = models.ForeignKey(
        "groups.Group",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_author_reference_group",
    )


class DocumentReferenceAttesterPartyReference(BaseReference):
    """document reference attester party reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attester_party_references_identifier",
    )
    patient = models.ForeignKey(
        "patients.Patient",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attester_party_reference_patient",
    )
    related_person = models.ForeignKey(
        "relatedpersons.RelatedPerson",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attester_party_reference_related_person",
    )
    practitioner = models.ForeignKey(
        "practitioners.Practitioner",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attester_party_reference_practitioner",
    )
    practitioner_role = models.ForeignKey(
        "practitionerroles.PractitionerRole",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attester_party_reference_practitioner_role",
    )
    organization = models.ForeignKey(
        "organizations.Organization",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attester_party_reference_organization",
    )
    group = models.ForeignKey(
        "groups.Group",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attester_party_reference_group",
    )


class DocumentReferenceAttester(TimeStampedModel):
    """document reference attester model."""

    mode = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attesters_mode",
    )
    time = models.DateTimeField(null=True)
    party = models.ForeignKey(
        DocumentReferenceAttesterPartyReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_attesters_party",
    )


class DocumentReferenceRelatesTo(TimeStampedModel):
    """document reference relates to."""

    code = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_relates_tos_code",
    )
    target = models.ForeignKey(
        "DocumentReferenceReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_relates_tos_target",
    )


class DocumentReferenceContentProfile(TimeStampedModel):
    """document reference content profile model."""

    value_coding = models.ForeignKey(
        Coding,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_content_profiles_value_coding",
    )
    value_uri = models.URLField(null=True)
    # TODO: value_canonical = models.ForeignKey("Canonical", on_delete=models.DO_NOTHING, null=True)


class DocumentReferenceContent(TimeStampedModel):
    """document reference content model."""

    attachment = models.ForeignKey(
        "base.Attachment",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_contents_attachment",
    )
    profile = models.ManyToManyField(
        DocumentReferenceContentProfile,
        related_name="document_reference_contents_profile",
        blank=True,
    )


class DocumentReferenceContextReference(TimeStampedModel):
    """document reference context reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_context_references_identifier",
    )
    appointment = models.ForeignKey(
        "appointments.Appointment",
        null=True,
        on_delete=models.DO_NOTHING,
        related_name="document_reference_context_reference_appointment",
    )
    encounter = models.ForeignKey(
        "encounters.Encounter",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_context_reference_encounter",
    )
    episode_of_care = models.ForeignKey(
        "episodeofcares.EpisodeOfCare",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_context_reference_episode_of_care",
    )


class DocumentReference(TimeStampedModel):
    """document reference model."""

    identifier = models.ManyToManyField(
        Identifier, blank=True, related_name="document_reference_identifier"
    )
    version = models.CharField(max_length=255, null=True)
    based_on = models.ManyToManyField(
        DocumentReferenceBasedOnReference,
        blank=True,
        related_name="document_reference_based_on",
    )
    status = models.CharField(
        max_length=255, null=True, choices=DocumentReferenceStatusChoices.choices
    )
    doc_status = models.CharField(
        max_length=255, null=True, choices=DocumentReferenceDocStatusChoices.choices
    )
    modality = models.ManyToManyField(
        CodeableConcept, related_name="document_reference_modalities", blank=True
    )
    type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_type",
    )
    category = models.ManyToManyField(
        CodeableConcept, related_name="document_reference_categories", blank=True
    )
    subject = models.ForeignKey(
        Reference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_subject",
    )
    context = models.ManyToManyField(
        DocumentReferenceContextReference,
        related_name="document_reference_contexts",
        blank=True,
    )
    event = models.ManyToManyField(
        CodeableReference, related_name="document_reference_events", blank=True
    )
    related = models.ManyToManyField(
        Reference, related_name="document_reference_related", blank=True
    )
    body_site = models.ManyToManyField(
        "bodystructures.BodyStructureCodeableReference",
        related_name="document_reference_body_sites",
        blank=True,
    )
    facility_type = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_facility_type",
    )
    practice_setting = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_practice_setting",
    )
    period = models.ForeignKey(
        Period,
        related_name="document_reference_source_patient_infos",
        null=True,
        on_delete=models.DO_NOTHING,
    )
    date = models.DateTimeField(null=True)
    author = models.ManyToManyField(
        DocumentReferenceAuthorReference,
        related_name="document_reference_authors",
        blank=True,
    )
    attester = models.ManyToManyField(
        DocumentReferenceAttester,
        related_name="document_reference_attesters",
        blank=True,
    )
    custodian = models.ForeignKey(
        "base.OrganizationReference",
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_custodian",
    )
    relates_to = models.ManyToManyField(
        DocumentReferenceRelatesTo,
        related_name="document_reference_relates_tos",
        blank=True,
    )
    description = models.TextField(null=True)
    security_label = models.ManyToManyField(
        CodeableConcept, related_name="document_reference_security_labels", blank=True
    )
    content = models.ManyToManyField(
        DocumentReferenceContent, related_name="document_reference_contents", blank=True
    )


class DocumentReferenceReference(BaseReference):
    """document reference reference model."""

    identifier = models.ForeignKey(
        Identifier,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_references_identifier",
    )
    document_reference = models.ForeignKey(
        DocumentReference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_references_document_reference",
    )


class DocumentReferenceCodeableReference(TimeStampedModel):
    """document reference codeable reference model."""

    concept = models.ForeignKey(
        CodeableConcept,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_codeable_references_concept",
    )
    reference = models.ForeignKey(
        Reference,
        on_delete=models.DO_NOTHING,
        null=True,
        related_name="document_reference_codeable_references_reference",
    )



"""Family Member History choices."""

from django.db import models
from django.utils.translation import gettext_lazy as _


class FamilyMemberHistoryStatus(models.TextChoices):
    """Family Member History status choices."""

    PARTIAL = "partial", _("Partial")
    COMPLETED = "completed", _("Completed")
    ENTERED_IN_ERROR = "entered-in-error", _("Entered in Error")
    HEALTH_UNKNOWN = "health-unknown", _("Health Unknown")



# Generated by Django 5.2 on 2025-05-02 14:24

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('immunizationevaluations', '0002_initial'),
        ('immunizationrecommendations', '0002_initial'),
        ('immunizations', '0003_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='immunizationrecommendationsupportingimmunizationreference',
            name='immunization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_recommendation_supporting_immunization_reference_immunization', to='immunizations.immunization'),
        ),
        migrations.AddField(
            model_name='immunizationrecommendationsupportingimmunizationreference',
            name='immunization_evolution',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='immunization_recommendation_supporting_immunization_reference_immunization_evolution', to='immunizationevaluations.immunizationevaluation'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('activitydefinitions', '0005_initial'),
        ('base', '0003_initial'),
        ('groups', '0001_initial'),
        ('healthcareservices', '0001_initial'),
        ('locations', '0001_initial'),
        ('medications', '0001_initial'),
        ('organizations', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='group',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_group', to='groups.group'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='healthcare_service',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_healthcare_service', to='healthcareservices.healthcareservice'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='identifier',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_identifier', to='base.identifier'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='location',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_location', to='locations.location'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='medication',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_medication', to='medications.medication'),
        ),
        migrations.AddField(
            model_name='activitydefinitionparticipanttypereference',
            name='organization',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='activity_definition_participant_type_reference_organization', to='organizations.organization'),
        ),
    ]



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0003_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='FamilyMemberHistoryCondition',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('contributed_to_death', models.BooleanField(null=True)),
                ('onset_string', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryParticipant',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryParticipantActorReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryProcedure',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('contributed_to_death', models.BooleanField(null=True)),
                ('performed_string', models.CharField(max_length=255, null=True)),
                ('performed_date_time', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryReasonCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistoryReasonReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='FamilyMemberHistory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('partial', 'Partial'), ('completed', 'Completed'), ('entered-in-error', 'Entered in Error'), ('health-unknown', 'Health Unknown')], max_length=255)),
                ('date', models.DateTimeField(null=True)),
                ('name', models.CharField(max_length=255, null=True)),
                ('born_date', models.DateTimeField(null=True)),
                ('born_string', models.CharField(max_length=255, null=True)),
                ('age_string', models.CharField(max_length=255, null=True)),
                ('estimated_age', models.BooleanField(null=True)),
                ('deceased_boolean', models.BooleanField(null=True)),
                ('deceased_date', models.DateTimeField(null=True)),
                ('deceased_string', models.CharField(max_length=255, null=True)),
                ('age_age', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_age_age', to='base.age')),
                ('age_range', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_age_range', to='base.range')),
                ('born_period', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_born_period', to='base.period')),
                ('data_absent_reason', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='family_member_history_data_absent_reason', to='base.codeableconcept')),
                ('deceased_age', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_deceased_age', to='base.age')),
                ('deceased_range', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='family_member_history_deceased_range', to='base.range')),
                ('identifier', models.ManyToManyField(blank=True, related_name='family_member_history_identifier', to='base.identifier')),
                ('note', models.ManyToManyField(blank=True, related_name='family_member_history_note', to='base.annotation')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""CoverageEligibilityRequests URL Configuration."""

from django.urls import path

from . import views

app_name = "coverageeligibilityrequests"


urlpatterns = [
    path(
        "coverageeligibilityrequests/",
        views.CoverageEligibilityRequestListView.as_view(),
        name="list-create",
    ),
    path(
        "coverageeligibilityrequests/<int:pk>/",
        views.CoverageEligibilityRequestDetailView.as_view(),
        name="detail",
    ),
]



"""Practitioners app configuration."""

import contextlib

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class PractitionersConfig(AppConfig):
    """Practitioners app configuration."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.practitioners"
    verbose_name = _("Practitioners")

    def ready(self):
        """Import signals."""
        with contextlib.suppress(ImportError):
            import dfhir.practitioners.signals  # noqa: F401



"""Allergy intolerances app configuration."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class AllergyintolerancesConfig(AppConfig):
    """Allergy intolerances app configuration."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.allergyintolerances"
    verbose_name = _("Allergy Intolerances")



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('accounts', '0002_initial'),
        ('appointments', '0002_initial'),
        ('base', '0003_initial'),
        ('careteams', '0002_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='DietPreference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('description', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterAdmission',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterBasedOnReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterCondition',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('description', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterDiagnosis',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterEpisodeOfCareReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterLocation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('planned', 'Planned'), ('active', 'Active'), ('reserved', 'Reserved'), ('completed', 'Completed')], max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterParticipant',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterParticipantActorReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterReason',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterReasonValueCodeableReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterReasonValueReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='EncounterReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SpecialArrangement',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('description', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='SpecialCourtesy',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('display', models.CharField(max_length=255, null=True)),
                ('description', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Encounter',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('planned', 'Planned'), ('in-progress', 'In Progress'), ('on-hold', 'On Hold'), ('discharged', 'Discharged'), ('completed', 'Completed'), ('cancelled', 'Cancelled'), ('discontinued', 'Discontinued'), ('entered-in-error', 'Entered in Error'), ('unknown', 'Unknown')], max_length=255, null=True)),
                ('planned_start_date', models.DateTimeField(null=True)),
                ('planned_end_date', models.DateTimeField(null=True)),
                ('account', models.ManyToManyField(blank=True, related_name='encounter_account', to='accounts.account')),
                ('actual_period', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='encounter_actual_period', to='base.period')),
                ('appointment', models.ManyToManyField(blank=True, related_name='encounter_appointment', to='appointments.appointmentreference')),
                ('care_team', models.ManyToManyField(blank=True, related_name='encounter_care_team', to='careteams.careteam')),
                ('diet_preference', models.ManyToManyField(blank=True, related_name='encounter_diet_preference', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""immunization evaluation views."""

from django.http import Http404
from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from dfhir.immunizationevaluations.models import ImmunizationEvaluation
from dfhir.immunizationevaluations.serializers import ImmunizationEvaluationSerializer


class ImmunizationEvaluationListView(APIView):
    """immunization evaluation list view."""

    permission_classes = [AllowAny]

    @extend_schema(responses={200: ImmunizationEvaluationSerializer(many=True)})
    def get(self, request):
        """Get immunization evaluation objects."""
        queryset = ImmunizationEvaluation.objects.all()
        serializer = ImmunizationEvaluationSerializer(queryset, many=True)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(
        request=ImmunizationEvaluationSerializer,
        responses={201: ImmunizationEvaluationSerializer},
    )
    def post(self, request):
        """Create immunization evaluation object."""
        serializer = ImmunizationEvaluationSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_201_CREATED)


class ImmunizationEvaluationDetailView(APIView):
    """immunization evaluation detail view."""

    def get_object(self, pk):
        """Get immunization evaluation object."""
        try:
            return ImmunizationEvaluation.objects.get(pk=pk)
        except ImmunizationEvaluation.DoesNotExist as err:
            raise Http404 from err

    @extend_schema(responses={200: ImmunizationEvaluationSerializer})
    def get(self, request, pk):
        """Get immunization evaluation object."""
        immunization_evaluation = self.get_object(pk)
        serializer = ImmunizationEvaluationSerializer(immunization_evaluation)
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={200: ImmunizationEvaluationSerializer})
    def patch(self, request, pk):
        """Update immunization evaluation object."""
        immunization_evaluation = self.get_object(pk)
        serializer = ImmunizationEvaluationSerializer(
            immunization_evaluation, data=request.data, partial=True
        )
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(serializer.data, status=status.HTTP_200_OK)

    @extend_schema(responses={204: ImmunizationEvaluationSerializer})
    def delete(self, request, pk):
        """Delete immunization evaluation object."""
        immunization_evaluation = self.get_object(pk)
        immunization_evaluation.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)



# Generated by Django 5.2 on 2025-04-23 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='MedicationDispense',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.CharField(choices=[('preparation', 'preparation'), ('in-progress', 'in_progress'), ('on_hold', 'on_hold'), ('completed', 'completed'), ('cancelled', 'cancelled'), ('entered-in-error', 'entered_in_error'), ('stopped', 'stopped'), ('declined', 'declined'), ('unknown', 'unknown')], max_length=255, null=True)),
                ('status_changed', models.DateTimeField(null=True)),
                ('recorded', models.DateTimeField(null=True)),
                ('when_prepared', models.DateTimeField(null=True)),
                ('when_handed_over', models.DateTimeField(null=True)),
                ('rendered_dosage_instructions', models.TextField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MedicationDispensePerformer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MedicationDispensePerformerActorReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MedicationDispenseReceiverReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MedicationDispenseSubstitution',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('was_substituted', models.BooleanField(default=False)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='MedicationDispenseSubstitutionResponsiblePartyReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



"""Specimen definitions urls."""

from django.urls import path

from . import views

app_name = "specimendefinitions"

urlpatterns = [
    path(
        "specimendefinitions/",
        views.SpecimenDefinitionListView.as_view(),
    ),
    path(
        "specimendefinitions/<int:pk>/",
        views.SpecimenDefinitionDetailView.as_view(),
    ),
]



"""Clinical impressions app config."""

from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ClinicalimpressionsConfig(AppConfig):
    """Clinical impressions app config."""

    default_auto_field = "django.db.models.BigAutoField"
    name = "dfhir.clinicalimpressions"
    verbose_name = _("Clinical Impressions")



"""Episode of Care views."""

from drf_spectacular.utils import extend_schema
from rest_framework import status
from rest_framework.permissions import AllowAny
from rest_framework.response import Response
from rest_framework.views import APIView

from .models import EpisodeOfCare
from .serializers import EpisodeOfCareSerializer


class EpisodeOfCareListView(APIView):
    """Episode of Care list view."""

    serializer = EpisodeOfCareSerializer
    permission_classes = [AllowAny]

    @extend_schema(responses={200, EpisodeOfCareSerializer(many=True)})
    def get(self, request):
        """Get all episodes of care."""
        episodes_of_care = EpisodeOfCare.objects.all()
        serializer = self.serializer(episodes_of_care, many=True)
        return Response(serializer.data)

    @extend_schema(
        request=EpisodeOfCareSerializer,
        responses={201, EpisodeOfCareSerializer},
    )
    def post(self, request):
        """Create a new episode of care."""
        serializer = self.serializer(data=request.data)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data, status=status.HTTP_201_CREATED)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)


class EpisodeOfCareDetailView(APIView):
    """Episode of Care detail view."""

    serializer = EpisodeOfCareSerializer

    def get_object(self, pk=None):
        """Get episode of care object."""
        try:
            return EpisodeOfCare.objects.get(pk=pk)
        except EpisodeOfCare.DoesNotExist:
            return Response(status=status.HTTP_404_NOT_FOUND)

    @extend_schema(responses={200, EpisodeOfCareSerializer})
    def get(self, request, pk):
        """Get an episode of care."""
        episode_of_care = self.get_object(pk)
        serializer = self.serializer(episode_of_care)
        return Response(serializer.data)

    @extend_schema(responses={200, EpisodeOfCareSerializer})
    def patch(self, request, pk):
        """Update an episode of care."""
        episode_of_care = self.get_object(pk)
        serializer = self.serializer(episode_of_care, data=request.data, partial=True)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)

    @extend_schema(responses={204})
    def delete(self, request, pk):
        """Delete an episode of care."""
        episode_of_care = self.get_object(pk)
        episode_of_care.delete()
        return Response(status=status.HTTP_204_NO_CONTENT)

    @extend_schema(responses={200, EpisodeOfCareSerializer})
    def put(self, request, pk):
        """Update an episode of care."""
        episode_of_care = self.get_object(pk)
        serializer = self.serializer(episode_of_care, data=request.data)
        if serializer.is_valid():
            serializer.save()
            return Response(serializer.data)
        return Response(serializer.errors, status=status.HTTP_400_BAD_REQUEST)



# Generated by Django 5.2 on 2025-04-23 12:46

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('base', '0002_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='DeviceMetricCalibration',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('state', models.CharField(choices=[('not-calibrated', 'Not Calibrated'), ('calibration-required', 'Calibration Required'), ('calibrated', 'Calibrated'), ('unspecified', 'Unspecified')], max_length=255, null=True)),
                ('time', models.DateTimeField(null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DeviceMetricReference',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('reference', models.CharField(max_length=255, null=True)),
                ('type', models.CharField(max_length=255, null=True)),
                ('display', models.CharField(max_length=255, null=True)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='DeviceMetric',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('operational_status', models.CharField(choices=[('on', 'on'), ('off', 'off'), ('standby', 'standby'), ('entered-in-error', 'Entered in Error')], max_length=255, null=True)),
                ('color', models.CharField(max_length=255, null=True)),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, related_name='device_metric_category', to='base.codeableconcept')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]
